Struct ExtSessionLockSurfaceV1
pub struct ExtSessionLockSurfaceV1 { /* private fields */ }wayland and Linux only.Expand description
a surface displayed while the session is locked
The client may use lock surfaces to display a screensaver, render a dialog to enter a password and unlock the session, or however else it sees fit.
On binding this interface the compositor will immediately send the first configure event. After making the ack_configure request in response to this event the client should attach and commit the first buffer. Committing the surface before acking the first configure is a protocol error. Committing the surface with a null buffer at any time is a protocol error.
The compositor is free to handle keyboard/pointer focus for lock surfaces however it chooses. A reasonable way to do this would be to give the first lock surface created keyboard focus and change keyboard focus if the user clicks on other surfaces.
See also the Request enum for this interface.
Implementations
impl ExtSessionLockSurfaceV1
impl ExtSessionLockSurfaceV1
pub fn configure(&self, serial: u32, width: u32, height: u32)
pub fn configure(&self, serial: u32, width: u32, height: u32)
the client should resize its surface
This event is sent once on binding the interface and may be sent again at the compositor’s discretion, for example if output geometry changes.
The width and height are in surface-local coordinates and are exact requirements. Failing to match these surface dimensions in the next commit after acking a configure is a protocol error.